#### STOKES BROKERS SURVEY ####

#### LIBRARIES, IMPORT DATA ####
library(foreign)
library(ggplot2)
library(tidyverse)
brokers <- read.dta("Broker_Survey_Final copy.dta")
voters <- read.dta("ArgentineVoterSurvey 2003.dta")


#### VARIABLE RENAMING, BASIC RECODING ####

brokers$sex <- brokers$q42a-1
#female = 1
brokers$edu <- brokers$q39
brokers$income <- brokers$q41
brokers$cloyal <- brokers$q17a
brokers$ployal <- brokers$q19
brokers$cswing <- brokers$q18
brokers$pswing <- brokers$q20

brokers$paid <- brokers$q11a
brokers$elected <- brokers$q43
brokers$elected[brokers$q43==2] <- 0
brokers$primjob <- brokers$q40a
brokers$primjob[brokers$q40a==2] <- 0


#### TABLE 1/BASIC DESCRIPTIVE STATISTICS - PAGE 9-10 ####

#SEX
mean(brokers$sex,na.rm=T)
table(brokers$sex)

#AGE
summary(lm(age ~ sex,data=brokers))
mean(brokers$age[brokers$sex==0],na.rm=T)
mean(brokers$age[brokers$sex==1],na.rm=T)
mean(brokers$age,na.rm=T)

#EDUCATION
brokers$highschool <- brokers$edu>4
brokers$hplus <- brokers$edu>5
brokers$college <- brokers$edu==9

summary(lm(highschool ~ sex,data=brokers))
mean(brokers$highschool[brokers$sex==0],na.rm=T)
mean(brokers$highschool[brokers$sex==1],na.rm=T)
mean(brokers$highschool,na.rm=T)

summary(lm(hplus ~ sex,data=brokers))
mean(brokers$hplus[brokers$sex==1],na.rm=T)
mean(brokers$hplus[brokers$sex==0],na.rm=T)

summary(lm(college ~ sex,data=brokers))
mean(brokers$college[brokers$sex==1],na.rm=T)
mean(brokers$college[brokers$sex==0],na.rm=T)


#INCOME
summary(lm(income ~ sex,data=brokers))
summary(lm(income ~ sex,data=brokers[brokers$primjob==1,]))
summary(lm(primjob ~ sex,data=brokers))

median(brokers$income[brokers$sex==1],na.rm=T)
# 1 = 0
# 2 = 1-1000 pesos
# 3 = 1001-2000 pesos
# 4 = 2001-3000 pesos
# 5 = 3001-4000 pesos
# 6 = 4001-5000 pesos
# 7 = 5001-7000 pesos
# 8 = 7001-9000 pesos
# 9 = 9001-12000 pesos
# 10 = >12000 pesos
median(brokers$income[brokers$sex==0],na.rm=T)
mean(brokers$income[brokers$sex==1],na.rm=T)
mean(brokers$income[brokers$sex==0],na.rm=T)

mean(brokers$primjob[brokers$sex==1],na.rm=T)
mean(brokers$primjob[brokers$sex==0],na.rm=T)

median(brokers$income[brokers$sex==1&brokers$primjob==1],na.rm=T)
median(brokers$income[brokers$sex==0&brokers$primjob==0],na.rm=T)

# OTHER JOBS
brokers$publicemployee <- 0
brokers$publicemployee[brokers$q40b=="1"|brokers$q40b=="1 y 15"|
                         brokers$q40b=="1 y 3"|brokers$q40b=="1 y 6"|
                         brokers$q40b=="1-4 y 15"|brokers$q40b=="1-4 y 9"|
                         brokers$q40b=="1, 4 y 9"|brokers$q40b=="1, 5 y 13"|
                         brokers$q40b=="1+3"] <- 1
brokers$privateemployee <- 0
brokers$privateemployee[brokers$q40b=="2"|
                         brokers$q40b=="1-4 y 15"|brokers$q40b=="1-4 y 9"] <- 1
brokers$selfemployed <- 0
brokers$selfemployed[brokers$q40b=="3"|
                         brokers$q40b=="1 y 3"|
                         brokers$q40b=="1-4 y 15"|brokers$q40b=="1-4 y 9"|
                         brokers$q40b=="1+3"|
                         brokers$q40b=="3 (cuida a un enfermo)"|brokers$q40b=="3 Y 11"|
                         brokers$q40b=="3 y 9"] <- 1
brokers$independentprofessional <- 0
brokers$independentprofessional[brokers$q40b=="4"|
                       brokers$q40b=="1-4 y 15"|brokers$q40b=="1-4 y 9"|
                       brokers$q40b=="1, 4 y 9"] <- 1
brokers$agriculture <- 0
brokers$agriculture[brokers$q40b=="5"|brokers$q40b=="1, 5 y 13"] <- 1
brokers$domestic <- 0
brokers$domestic[brokers$q40b=="6"|brokers$q40b=="1 y 6"] <- 1
brokers$rural <- 0
brokers$rural[brokers$q40b=="7"] <- 1
brokers$daylaborer <- 0
brokers$daylaborer[brokers$q40b=="8"] <- 1
brokers$teacher <- 0
brokers$teacher[brokers$q40b=="9"|brokers$q40b=="1-4 y 9"|
                       brokers$q40b=="1, 4 y 9"|
                       brokers$q40b=="3 y 9"|brokers$q40b=="9 y 11"] <- 1
brokers$businessowner <- 0
brokers$businessowner[brokers$q40b=="10"] <- 1
brokers$merchant <- 0
brokers$merchant[brokers$q40b=="11"|brokers$q40b=="11 y 14"|
                       brokers$q40b=="3 Y 11"|brokers$q40b=="9 y 11"] <- 1
brokers$student <- 0
brokers$student[brokers$q40b=="12"] <- 1
brokers$retired <- 0
brokers$retired[brokers$q40b=="13"|brokers$q40b=="1, 5 y 13"] <- 1
brokers$unemployed <- 0
brokers$unemployed[brokers$q40b=="14"] <- 1
brokers$other <- 0
brokers$other[brokers$q40b=="15"|brokers$q40b=="1 y 15"|
                       brokers$q40b=="1-4 y 15"|
                       brokers$q40b=="15 (Alquileres por herencia)"|
                       brokers$q40b=="15 (Pensi\xf3n por fallecimiento del marido/ alquileres)"] <- 1
jobs <- brokers %>%
  group_by(sex)%>%
  summarise(public=sum(publicemployee),private=sum(privateemployee),
            selfemployed=sum(selfemployed),independentprofessional=sum(independentprofessional),
            agriculture=sum(agriculture),domestic=sum(domestic),
            rural=sum(rural),daylaborer=sum(daylaborer),teacher=sum(teacher),
            businessowner=sum(businessowner),merchant=sum(merchant),student=sum(student),
            retired=sum(retired),unemployed=sum(unemployed),other=sum(other))


#### GIFT TYPES PAGE 26 ####
table(as.numeric(voters$p5))
voters$brokersex <- as.numeric(voters$p5)-1
voters$brokersex[voters$brokersex==0|voters$brokersex==4] <- NA
table(voters$brokersex)
#1=male
#2=female
#3=both
voters$brokerfemale <- as.numeric(voters$brokersex==2)

#CASH
voters$cash <- as.numeric(voters$p2a5)-1
mean(voters$cash[voters$brokersex==2],na.rm=T)
mean(voters$cash[voters$brokersex==1],na.rm=T)
summary(lm(cash ~ brokerfemale,data=voters))

#ASSISTANCE
voters$med <- as.numeric(voters$p2a10)-1
voters$tram <- as.numeric(voters$p2a9)-1
voters$becas <- as.numeric(voters$p2a11)-1
voters$assistance <- as.numeric(voters$med==1|voters$tram==1|voters$becas==1)

mean(voters$assistance[voters$brokersex==2],na.rm=T)
mean(voters$assistance[voters$brokersex==1],na.rm=T)


#### TABLE 2/TARGETING PAGE 27 ####

brokers$total <- brokers$cloyal+brokers$ployal+brokers$pswing+brokers$cswing
table(brokers$total)
### NOTE THAT MANY OF THESE DO NOT SUM TO 10 

#CREATING PROPORTIONAL VARIABLES TO CORRECT FOR THIS
brokers$cl <- brokers$cloyal/brokers$total
brokers$pl <- brokers$ployal/brokers$total
brokers$cs <- brokers$cswing/brokers$total
brokers$ps <- brokers$pswing/brokers$total

summary(lm(cl ~ sex,data=brokers))
summary(lm(pl ~ sex,data=brokers))
summary(lm(cs ~ sex,data=brokers))
summary(lm(ps ~ sex,data=brokers))

#ROBUSTNESS CHECK
summary(lm(cl ~ sex + edu + age,data=brokers))
summary(lm(pl ~ sex + edu + age,data=brokers))
summary(lm(cs ~ sex + edu + age,data=brokers))
summary(lm(ps ~ sex + edu + age,data=brokers))


# UNCORRECTED VERSION:
summary(lm(cloyal ~ sex,data=brokers))
summary(lm(ployal ~ sex,data=brokers))
summary(lm(cswing ~ sex,data=brokers))
summary(lm(pswing ~ sex,data=brokers))

summary(lm(cloyal ~ sex + edu + age,data=brokers))
summary(lm(ployal ~ sex + edu + age,data=brokers))
summary(lm(cswing ~ sex + edu + age,data=brokers))
summary(lm(pswing ~ sex + edu + age,data=brokers))


#### ELECTION PAGE 28 ####

#PROPORTION WHO ARE CONCEJALES
brokers$elected <- -(brokers$q43-2)
mean(brokers$elected[brokers$sex==1],na.rm=T)
mean(brokers$elected[brokers$sex==0],na.rm=T)
summary(lm(elected~ sex,data=brokers))

#win or lose first election
brokers$e1 <- -(brokers$q8d-2)
mean(brokers$e1[brokers$sex==1],na.rm=T)
mean(brokers$e1[brokers$sex==0],na.rm=T)
summary(lm(e1 ~ sex,data=brokers))


#ran for office
brokers$ran <- -(brokers$q8a-2)
summary(lm(ran ~ sex,data=brokers))







